@@ -74,3 +74,17 @@ class Spotlight_Vulnerabilities(ServiceClass):
                                    verify=self.ssl_verify
                                    )
         return returned
+
+    def getRemediations(self: object, ids) -> dict:
+        """Get details on remediations by providing one or more IDs. """
+        # [GET] Not in swagger
+        ID_LIST = str(parse_id_list(ids)).replace(",", "&ids=")
+        FULL_URL = self.base_url + '/spotlight/entities/remediations/v2?ids={}'.format(ID_LIST)
+        HEADERS = self.headers
+        returned = service_request(caller=self,
+                                   method="GET",
+                                   endpoint=FULL_URL,
+                                   headers=HEADERS,
+                                   verify=self.ssl_verify
+                                   )
+        return returned
